package at.xaxa.ledger.ui.category

import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.runtime.Composable
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.unit.dp
import androidx.lifecycle.viewmodel.compose.viewModel
import at.xaxa.ledger.ui.AppViewModelProvider
import at.xaxa.ledger.ui.ButtonSuccess
import at.xaxa.ledger.ui.CategoryCard

@Composable
fun CategoryOverview(
    onButtonClick: () -> Unit,
    modifier: Modifier = Modifier,
    onCardClick: (Int) -> Unit,
    categoryViewModel: CategoryViewModel = viewModel(factory = AppViewModelProvider.Factory)
){

    val categories by categoryViewModel.categoryUiState.categories.collectAsState(initial = emptyList())

    Column(
        modifier = modifier
            .fillMaxSize()
            .padding(16.dp, 0.dp),
        horizontalAlignment = Alignment.CenterHorizontally
    ) {
        LazyColumn(
            Modifier.weight(1f)
        ) {
            items(categories) { item ->
                Column(
                    modifier = Modifier.padding(vertical = 4.dp)
                ) {
                    CategoryCard(
                        modifier = modifier,
                        name = item.categoryName,
                        iconId = item.icon,
                        onClick = { onCardClick(item._id) }
                    )
                }
            }
        }

        // Sticky footer content
        Box(
            modifier = Modifier
                .fillMaxWidth(),
            contentAlignment = Alignment.Center
        ) {
            ButtonSuccess(modifier = Modifier, "Add Category", onClick = { onButtonClick() })
        }
    }
}