package at.xaxa.ledger.ui.entry.add

import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.DropdownMenuItem
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.ExposedDropdownMenuBox
import androidx.compose.material3.ExposedDropdownMenuDefaults
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableIntStateOf
import androidx.compose.runtime.mutableLongStateOf
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.unit.dp
import androidx.lifecycle.viewmodel.compose.viewModel
import at.xaxa.ledger.data.Entry
import at.xaxa.ledger.ui.AppViewModelProvider
import at.xaxa.ledger.ui.ButtonSuccess
import at.xaxa.ledger.ui.DatePickerDocked

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun Add(
    modifier: Modifier = Modifier,
    onCardClick: () -> Unit,
    addViewModel: AddViewModel = viewModel(factory = AppViewModelProvider.Factory)
) {
    var name by remember { mutableStateOf("") }
    val state by addViewModel.addUiState.entries.collectAsState(initial = emptyList())
    val categories by addViewModel.categoryUiState.categories.collectAsState(initial = emptyList())

    var spending by remember { mutableStateOf("") }
    var selectedDate by remember { mutableLongStateOf(0) }
    var expanded by remember { mutableStateOf(false) }
    var selectedItem by remember { mutableStateOf("") }
    var selectedCategory by remember { mutableIntStateOf(-1) }

    Column(
        modifier = modifier
            .fillMaxSize()
            .padding(16.dp, 0.dp),
        horizontalAlignment = Alignment.CenterHorizontally
    ) {
        Column(
            Modifier.weight(1f)
        ) {
            OutlinedTextField(
                value = name,
                onValueChange = { name = it },
                label = { Text("Name") },
                modifier = Modifier
                    .fillMaxWidth()
            )
            OutlinedTextField(
                value = spending,
                onValueChange = { spending = it },
                label = { Text("Spending") },
                modifier = Modifier
                    .fillMaxWidth()
            )

            ExposedDropdownMenuBox(
                expanded = expanded,
                onExpandedChange = { expanded = it }
            ) {
                // TextField to display the selected item and trigger the dropdown
                OutlinedTextField(
                    value = selectedItem,
                    onValueChange = {},
                    label = { Text("Category") },
                    readOnly = true,
                    trailingIcon = {
                        ExposedDropdownMenuDefaults.TrailingIcon(expanded = expanded)
                    },
                    modifier = Modifier
                        .menuAnchor()
                        .fillMaxWidth()
                )

                // Dropdown menu
                ExposedDropdownMenu(
                    expanded = expanded,
                    onDismissRequest = { expanded = false }
                ) {
                    categories.forEach { item ->
                        DropdownMenuItem(
                            text = { Text(text = item.categoryName) },
                            onClick = {
                                selectedItem = item.categoryName
                                selectedCategory = item._id
                                expanded = false
                            }
                        )
                    }
                }
            }

            DatePickerDocked{
                dateMilis -> selectedDate = dateMilis
            }
        }

        Box(
            modifier = Modifier
                .fillMaxWidth(),
            contentAlignment = Alignment.Center
        ) {
            ButtonSuccess(
                modifier = Modifier,
                "Add Transaction",
                onClick = {
                    if (name.isNotBlank() && spending.toFloat() != 0f && selectedDate != 0L && selectedCategory != -1) {
                        val newEntry = Entry(
                            id = 0,
                            name = name,
                            amount = spending.toFloat(),
                            date = selectedDate,
                            categoryID = selectedCategory
                        )
                        addViewModel.addEntryToDB(newEntry)
                        onCardClick()
                    }
                }
            )
        }
    }
}
